import uvicorn
from fastapi import FastAPI, Request
from fastapi.responses import HTMLResponse
from fastapi.staticfiles import StaticFiles
from fastapi.templating import Jinja2Templates
from pydantic import BaseModel, constr

from src.change_url.change_url import change_url

app = FastAPI()

app.mount("/static", StaticFiles(directory="static"), name="static")

templates = Jinja2Templates(directory="templates")


@app.get("/", response_class=HTMLResponse)
async def index(request: Request):
    return templates.TemplateResponse("index.html", {"request": request})


class UrlModel(BaseModel):
    text: constr(min_length=1)


@app.post('/changeurl')
async def changeurl(url_model: UrlModel):
    text = url_model.text
    res, js_type = change_url(text)
    return {
        'res': res,
        'msg': js_type
    }


if __name__ == "__main__":
    uvicorn.run(app)
