import os
import time
import schedule
from loguru import logger

from src.core.message_client import send_message
from src.core.util import get_curr_day
from src.entity.finance import get_net_win_by_user
from src.entity.pay_record import get_pay_failed_by_user
from src.entity.user import get_user_by_username_and_password
from src.entity.visual_list import text_count_by_user

# 日志配置
logger.add("debug.log", format="{time} {level} {message}", level="DEBUG", rotation="1 week", compression="zip")


def execute_task(task_func, username, password):
    try:
        logger.info(f'Running {task_func.__name__} for username: {username}')
        user = get_user_by_username_and_password(username, password)
        message = task_func(user, get_curr_day())  # Assuming all tasks take a 'user' and 'date'
        send_message(user.bot_token, user.count_group_id, message)
        logger.info(f'Finished {task_func.__name__} for username: {username}')
    except Exception as e:  # Consider catching more specific exceptions if possible
        logger.error(f'Error running {task_func.__name__} for username: {username}, Error: {e}')
        logger.exception(e)  # This will log the full stack trace


def job_count(user, date):
    return text_count_by_user(user, date)


def query_failed_deposit(user, date):
    return get_pay_failed_by_user(user, date)


def query_net_win(user, date):
    return get_net_win_by_user(user, date)


if __name__ == '__main__':
    logger.info('Starting scheduled tasks')

    # Get credentials from environment variables
    username = os.getenv('MY_APP_USERNAME', 'default_username')
    password = os.getenv('MY_APP_PASSWORD', 'default_password')

    times = ['10:50', '14:40', '17:40', '20:40', '21:40', '23:59']

    for time_str in times:
        schedule.every().day.at(time_str).do(execute_task, job_count, username, password)
        schedule.every().day.at(time_str).do(execute_task, query_net_win, username, password)

    schedule.every().day.at('23:59').do(execute_task, query_failed_deposit, username, password)

    while True:
        schedule.run_pending()
        time.sleep(10)